We get a 1.5% speedup by inlining jstring_
commit91eb1633b6759b7b009bd5b31fe47a11c85a6221
authorBryan O'Sullivan <bos@serpentine.com>
dateThu 3 Feb 2011, 18:59 (16 years ago)
parent4474420
Data/Aeson/Parser.hs+1
@@ -94,6 +94,7 @@ jstring_ = do
9494 if backslash `B.elem` s
9595 then decodeUtf8 <$> reparse unescape s
9696 else return (decodeUtf8 s)
97+{-# INLINE jstring_ #-}
9798
9899reparse :: Parser a -> ByteString -> Parser a
99100reparse p s = case (case parse p s of {Partial k -> k ""; r -> r}) of